[PATCH 13/40] expo: Rename exp_set_text_mode()

Simon Glass sjg at chromium.org
Thu Jun 1 18:22:37 CEST 2023


Rename this function to match its peers, using the full "expo' prefix.

Signed-off-by: Simon Glass <sjg at chromium.org>
---

 boot/bootflow_menu.c | 2 +-
 boot/expo.c          | 2 +-
 include/expo.h       | 4 ++--
 test/boot/expo.c     | 2 +-
 4 files changed, 5 insertions(+), 5 deletions(-)

diff --git a/boot/bootflow_menu.c b/boot/bootflow_menu.c
index de0f44535690..7c1abe5772cd 100644
--- a/boot/bootflow_menu.c
+++ b/boot/bootflow_menu.c
@@ -209,7 +209,7 @@ int bootflow_menu_run(struct bootstd_priv *std, bool text_mode,
 		return log_msg_ret("scn", ret);
 
 	if (text_mode)
-		exp_set_text_mode(exp, text_mode);
+		expo_set_text_mode(exp, text_mode);
 
 	done = false;
 	do {
diff --git a/boot/expo.c b/boot/expo.c
index bfdda9570c60..e7c81a3983d3 100644
--- a/boot/expo.c
+++ b/boot/expo.c
@@ -97,7 +97,7 @@ int expo_set_display(struct expo *exp, struct udevice *dev)
 	return 0;
 }
 
-void exp_set_text_mode(struct expo *exp, bool text_mode)
+void expo_set_text_mode(struct expo *exp, bool text_mode)
 {
 	exp->text_mode = text_mode;
 }
diff --git a/test/boot/expo.c b/test/boot/expo.c
index 56a22ba9b066..70750d307ffa 100644
--- a/test/boot/expo.c
+++ b/test/boot/expo.c
@@ -507,7 +507,7 @@ static int expo_render_image(struct unit_test_state *uts)
 	ut_assert_console_end();
 
 	/* now try in text mode */
-	exp_set_text_mode(exp, true);
+	expo_set_text_mode(exp, true);
 	ut_assertok(expo_render(exp));
 
 	ut_assert_nextline("U-Boot    :    Boot Menu");
diff --git a/include/expo.h b/include/expo.h
index 06f5629e03f8..f77ee7085192 100644
--- a/include/expo.h
+++ b/include/expo.h
@@ -306,12 +306,12 @@ int expo_set_scene_id(struct expo *exp, uint scene_id);
 int expo_render(struct expo *exp);
 
 /**
  * exp_set_text_mode() - Controls whether the expo renders in text mode
  *
  * @exp: Expo to update
  * @text_mode: true to use text mode, false to use the console
  */
-void exp_set_text_mode(struct expo *exp, bool text_mode);
+void expo_set_text_mode(struct expo *exp, bool text_mode);
 
 /**
  * scene_new() - create a new scene in a expo
@@ -306,12 +306,12 @@ int expo_set_scene_id(struct expo *exp, uint scene_id);
 
 /**
- * exp_set_text_mode() - Controls whether the expo renders in text mode
+ * expo_set_text_mode() - Controls whether the expo renders in text mode
  *
  * @exp: Expo to update
-- 
2.41.0.rc0.172.g3f132b7071-goog



More information about the U-Boot mailing list